Method: Origami::PDF::Parser#initialize
- Defined in:
- lib/origami/parsers/pdf.rb
#initialize(params = {}) ⇒ Parser
Returns a new instance of Parser.
32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/origami/parsers/pdf.rb', line 32 def initialize(params = {}) = { :password => '', # Default password being tried when opening a protected document. :prompt_password => Proc.new { print "Password: " gets.chomp }, # Callback procedure to prompt password when document is encrypted. :force => false # Force PDF header detection }.update(params) super() end |